@@ -21,17 +21,18 @@ def get_header(config_reader: ConfigReaderAndWriter, user: str, password: str, r
     config_all = config_reader.get_config()
     if config_reader.profile not in config_all and config_reader.profile != "default":
         raise CLIError(ConfigReaderAndWriter.MESSAGES["profileError"].format(config_reader.profile))
-    elif config_reader.profile not in config_all and not request_address:
-        raise CLIError(ConfigReaderAndWriter.MESSAGES["noInit"].format(config_reader.profile))
 
     # Get request address from argument, environment variable or config (in that order)
     if not request_address and os.environ.get('GEOSPOCK_REQUEST_ADDRESS') is not None:
         request_address = os.environ.get('GEOSPOCK_REQUEST_ADDRESS')
+    elif not request_address and config_reader.profile in config_all:
+        request_address = config_all[config_reader.profile]["request_address"]
     elif not request_address:
-        request_address = config_reader.config["request_address"]
+        raise CLIError("No request-address provided - please provide in the command line, as the " +
+                       "GEOSPOCK_REQUEST_ADDRESS environment variable or by using `geospock login`.")
 
     # If using GeoSpock 3.0
-    if "auth0_url" in config_all[config_reader.profile]:
+    if config_reader.profile in config_all and "auth0_url" in config_all[config_reader.profile]:
         all_credentials = config_reader.get_all_credentials_from_file()
         auth = Authorizer(config_reader)
         if all_credentials is None or config_reader.profile not in all_credentials:
